#define COMPILATION_OPTIONS "echoping 6.0.2 compiled with cc on arch-nspawn-6314 (i486-pc-linux-gnu)\n at 2024-09-09 with options:\n\nHTTP: enabled\nICP: disabled \nOPENSSL: enabled\nGNUTLS: disabled \nSMTP: enabled\nLIBIDN: enabled\nTOS: enabled\nPRIORITY: enabled\n\nPlugins are searched in /usr/lib/echoping."

/* $Id: compilation.h.in 377 2007-03-12 20:48:05Z bortz $ */
